@@ -17,6 +17,11 @@
 import os
 import sys
 
+try:
+    from queue import Empty
+except ImportError:
+    from Queue import Empty
+
 from pybuilder.core import init, use_plugin, task, description
 from pybuilder.utils import execute_command, Timer
 from pybuilder.terminal import print_text_line, print_file_content, print_text
@@ -26,10 +31,6 @@ from pybuilder.terminal import styled_text, fg, GREEN, MAGENTA, GREY
 
 use_plugin("python.core")
 
-FINISHED_SYMBOL = "-"
-PENDING_SYMBOL = "/"
-WAITING_SYMBOL = "|"
-
 
 @init
 def init_test_source_directory(project):
@@ -100,8 +101,18 @@ def run_integration_tests_in_parallel(project, logger):
                 report_item = run_single_test(
                     logger, project, reports_dir, test, not progress.can_be_displayed)
                 reports.put(report_item)
-            except:
+            except Empty:
                 break
+            except Exception as e:
+                logger.error("Failed to run test %r : %s" % (test, str(e)))
+                failed_report = {
+                    "test": test,
+                    "test_file": test,
+                    "time": 0,
+                    "success": False
+                }
+                reports.put(failed_report)
+                continue
 
     pool = []
     for i in range(worker_pool_size):
@@ -114,9 +125,7 @@ def run_integration_tests_in_parallel(project, logger):
     while not progress.is_finished:
         finished_tests_count = reports.qsize()
         progress.update(finished_tests_count)
-        if progress.can_be_displayed:
-            bar = progress.render()
-            print_text(bar, flush=True)
+        progress.render_to_terminal()
         time.sleep(.5)
 
     progress.mark_as_finished()
@@ -152,7 +161,8 @@ def discover_integration_tests_for_project(project):
 def add_additional_environment_keys(env, project):
     additional_environment = project.get_property(
         "integrationtest_additional_environment", {})
-    # TODO: assert that additional env is a map
+    if not isinstance(additional_environment, dict):
+        raise ValueError("Additional environment %r is not a map." % additional_environment)
     for key in additional_environment:
         env[key] = additional_environment[key]
 
@@ -215,6 +225,18 @@ def run_single_test(logger, project, reports_dir, test, output_test_names=True):
 
 
 class TaskPoolProgress(object):
+    """
+    Class that renders progress for a set of tasks run in parallel.
+    The progress is based on
+    * the amount of total tasks, which must be static
+    * the amount of workers running in parallel.
+    The bar can be updated with the amount of tasks that have been successfully
+    executed and render its progress.
+    """
+
+    FINISHED_SYMBOL = "-"
+    PENDING_SYMBOL = "/"
+    WAITING_SYMBOL = "|"
 
     def __init__(self, total_tasks_count, workers_count):
         self.total_tasks_count = total_tasks_count
@@ -225,14 +247,18 @@ class TaskPoolProgress(object):
         self.finished_tasks_count = finished_tasks_count
 
     def render(self):
-        finished_tests_progress = styled_text(FINISHED_SYMBOL * self.finished_tasks_count, fg(GREEN))
+        finished_tests_progress = styled_text(self.FINISHED_SYMBOL * self.finished_tasks_count, fg(GREEN))
         running_tests_count = self.running_tests_count
-        running_tests_progress = styled_text(PENDING_SYMBOL * running_tests_count, fg(MAGENTA))
+        running_tests_progress = styled_text(self.PENDING_SYMBOL * running_tests_count, fg(MAGENTA))
         waiting_tests_count = self.waiting_tests_count
-        waiting_tests_progress = styled_text(WAITING_SYMBOL * waiting_tests_count, fg(GREY))
+        waiting_tests_progress = styled_text(self.WAITING_SYMBOL * waiting_tests_count, fg(GREY))
 
         return "\r[%s%s%s]" % (finished_tests_progress, running_tests_progress, waiting_tests_progress)
 
+    def render_to_terminal(self):
+        if self.can_be_displayed:
+            print_text(self.render(), flush=True)
+
     def mark_as_finished(self):
         if self.can_be_displayed:
             print_text_line()
